For convenience, the strategy calls are performed within this function so the
user does not necessarily have to have run them previously. A non-thresholded
set of strategies will be exported. If only a thresholded subset should be
exported, then this can be achieved by performing thresholding separately and
passing the rownames to this function as the parameter tracks.
If file is supplied, the file extension will be used to determine
which format to save the file in. The formats ".csv", ".csv2" (see
write.table for details of the formats), ".tsv" (
tab-delimited text; can also be written as ".txt" or ".tab") and ".xlsx"
(default) are currently supported. If the file extension is not in this list,
the data will be written as tab-delimited text with a warning. Note that the
Excel '.xlsx' format is supported, but the older '.xls' is not.